isAllNotNullOrEmpty function

bool isAllNotNullOrEmpty(
  1. List objects
)

Checks if all objects in a list are not null and not empty

@param objects The list of objects to check @return true if all objects in the list are not null and not empty, false otherwise

Implementation

bool isAllNotNullOrEmpty(List objects) {
  return !isOneNullOrEmpty(objects);
}