isNullOrEmpty function
Checks if an object is null or empty
@param object The object to check @return true if the object is null or empty, false otherwise
Implementation
bool isNullOrEmpty(dynamic object) {
return !isNotNullOrEmpty(object);
}
Checks if an object is null or empty
@param object The object to check @return true if the object is null or empty, false otherwise
bool isNullOrEmpty(dynamic object) {
return !isNotNullOrEmpty(object);
}