isOneNullOrEmpty function

bool isOneNullOrEmpty(
  1. List objects
)

Checks if any object in a list is null or empty

@param objects The list of objects to check @return true if any object in the list is null or empty, false otherwise

Implementation

bool isOneNullOrEmpty(List objects) {
  for (dynamic item in objects) {
    if (isNullOrEmpty(item)) {
      return true;
    }
  }
  return false;
}