AppBaseScreen constructor

const AppBaseScreen({
  1. Key? key,
  2. required Widget child,
  3. String? title,
  4. AppBar? appBar,
  5. EdgeInsets contentPadding = const EdgeInsets.symmetric(horizontal: 16),
})

Creates an AppBaseScreen.

child is the main content widget of the screen. title is the title to display in the app bar. appBar is an optional custom AppBar to use instead of the default one. contentPadding is the padding to apply around the child widget.

Implementation

const AppBaseScreen(
    {super.key,
    required this.child,
    this.title,
    this.appBar,
    this.contentPadding = const EdgeInsets.symmetric(horizontal: 16)});