AppNavigator class
A utility class for managing navigation within the application. This class provides static methods to navigate between different screens and handle various navigation operations like popping screens or showing bottom sheets.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addMockApi(
{MockApi? mockApi}) → Future - Navigates to the add mock API screen
-
apiDetail(
{required RequestModel requestModel}) → Future - Navigates to the API detail screen
-
apiScreenApi(
) → Future - Navigates to the API screen
-
bottomSheet(
Widget child, {required BuildContext context}) → Future - Shows a bottom sheet
-
emailsScreen(
) → Future - Navigates to the email screen
-
home(
) → Future - Navigates to the home screen
-
mockApi(
BuildContext? context) → Future - Navigates to the mock API screen
-
pop(
{dynamic result, }) → Future - Pops the current screen off the navigation stack
-
toNamed(
String name) → Future - Pushes a named route onto the navigation stack
-
toScreen(
Widget screen, String name) → Future - Pushes a screen onto the navigation stack
Constants
- addMockApiName → const String
- Route name for the add mock API screen
- apiDetailName → const String
- Route name for the API detail screen
- apiScreenName → const String
- Route name for the API screen
- emailName → const String
- Route name for the email screen
- homeName → const String
- Route name for the home screen
- mockApiName → const String
- Route name for the mock API screen