apiScreenApi static method
Navigates to the API screen
Returns a Future that completes when the navigation is finished
Implementation
static Future apiScreenApi() async {
return await toScreen(const MockApiScreen(), apiScreenName);
}
Navigates to the API screen
Returns a Future that completes when the navigation is finished
static Future apiScreenApi() async {
return await toScreen(const MockApiScreen(), apiScreenName);
}