bottomSheet static method

Future bottomSheet(
  1. Widget child, {
  2. required BuildContext context,
})

Shows a bottom sheet

child - The widget to display in the bottom sheet context - The BuildContext for the bottom sheet

Returns a Future that completes when the bottom sheet is shown

Implementation

static Future bottomSheet(Widget child,
    {required BuildContext context}) async {
  return await showModalBottomSheet(
      context: context,
      builder: (BuildContext context) {
        return child;
      },
      useSafeArea: true,
      isScrollControlled: true);
}