emailsScreen static method
Navigates to the email screen
Returns a Future that completes when the navigation is finished
Implementation
static Future emailsScreen() async {
return await toScreen(const SendEmailScreen(), emailName);
}
Navigates to the email screen
Returns a Future that completes when the navigation is finished
static Future emailsScreen() async {
return await toScreen(const SendEmailScreen(), emailName);
}