home static method
Navigates to the home screen
Returns a Future that completes when the navigation is finished
Implementation
static Future home() async {
return await toScreen(DevLoggerUILib(), homeName);
}
Navigates to the home screen
Returns a Future that completes when the navigation is finished
static Future home() async {
return await toScreen(DevLoggerUILib(), homeName);
}