mockApi static method
Navigates to the mock API screen
Returns a Future that completes when the navigation is finished
Implementation
static Future mockApi(BuildContext? context) async {
return await toNamed(mockApiName);
}
Navigates to the mock API screen
Returns a Future that completes when the navigation is finished
static Future mockApi(BuildContext? context) async {
return await toNamed(mockApiName);
}