defaultTextStyle property
Default text style for general use in the app.
Implementation
final TextStyle defaultTextStyle = const TextStyle(
fontSize: 14,
color: Colors.black,
fontWeight: FontWeight.w500,
height: 1.5);
Default text style for general use in the app.
final TextStyle defaultTextStyle = const TextStyle(
fontSize: 14,
color: Colors.black,
fontWeight: FontWeight.w500,
height: 1.5);