dev_logger_ui/dev_logger_ui library
Provides the main API Logger class and related types for API logging, overlay, and event management.
This file defines the DevLoggerUI singleton, its initialization, and event handling for API logging.
Classes
- DevLoggerUI
- The main API Logger singleton class for managing API logging, overlays, and events.
Mixins
- EmailManager
- Mixin that manages email sending and email address storage for API logging.
- ErrorManager
- Mixin that provides error management for API logging.
- HiddenApiManager
- Mixin that manages hidden APIs for API logging.
- MockManager
- Mixin that manages mock APIs for API logging.
- RequestManager
- Mixin that manages API requests for API logging.
Typedefs
-
OnErrorModelChanged
= void Function(List<
ErrorModel> ) - Signature for a callback that is called when the list of ErrorModel changes.
- OnNewError = void Function(FlutterErrorDetails)
- Signature for a callback that is called when a new FlutterErrorDetails is reported.
- OnRouteApiScreen = void Function(bool isShowed)
- Signature for a callback that is called when the API screen is shown or hidden.
-
SendTextFunction
= Future<
String?> Function({required String body, required String email, required String title}) - Signature for a function that sends text via email.