addMapRequestOption method
Adds a request model to the map for the given RequestOptions.
Implementation
void addMapRequestOption(RequestOptions options, RequestModel model) {
if (!isLogEnabled) return;
mapRequestOptions[options] = model;
}
Adds a request model to the map for the given RequestOptions.
void addMapRequestOption(RequestOptions options, RequestModel model) {
if (!isLogEnabled) return;
mapRequestOptions[options] = model;
}