ValueFromResponse class

Holds strategies for extracting values from API responses.

Constructors

ValueFromResponse({GetValueFromResponse<bool>? checkApiSuccess, GetValueFromResponse<String?>? getErrorMessage, GetValueFromResponse<MapEntry<String, dynamic>?>? getErrorCode})
Creates a ValueFromResponse with optional custom strategies.

Properties

checkApiSuccess GetValueFromResponse<bool?>?
Function to check if the API response indicates success.
getter/setter pair
getErrorCode GetValueFromResponse<MapEntry<String, dynamic>?>?
Function to extract the error code from the API response.
getter/setter pair
getErrorMessage GetValueFromResponse<String?>?
Function to extract the error message from the API response.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited