FileName class
A class for managing file names with name and type
This class represents a file with a name and type, and provides functionality to get the full file name.
Properties
Methods
-
getFileName(
) → String - Gets the full file name
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited