getFileName method
Gets the full file name
@return The full file name in the format "name.type"
Implementation
String getFileName() {
return "$name.$type";
}
Gets the full file name
@return The full file name in the format "name.type"
String getFileName() {
return "$name.$type";
}