file_save_manager library
File save manager implementation
This library provides an implementation of the SaveManager abstract class that saves data to local files using the device's application documents directory.
File save manager implementation
This library provides an implementation of the SaveManager abstract class that saves data to local files using the device's application documents directory.