FileSaveManager class

Inheritance

Constructors

FileSaveManager()

Properties

filePath String?
The file path for the cache file
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String key) Future
Gets a value
inherited
getBool(String key) Future<bool?>
Gets a boolean value
override
getDouble(String key) Future<double?>
Gets a double value
override
getInt(String key) Future<int?>
Gets an integer value
override
getString(String key) Future<String?>
Gets a string value
override
hasKey(String key) Future<bool>
Checks if a key exists in the cache
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<bool>
Removes a key from the cache
override
saveBool(String key, bool value) Future<bool>
Saves a boolean value
override
saveDouble(String key, double value) Future<bool>
Saves a double value
override
saveInt(String key, int value) Future<bool>
Saves an integer value
override
saveString(String key, String value) Future<bool>
Saves a string value
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited