getBool method
Gets a boolean value
@param key The key to retrieve the boolean from @return A Future that resolves to the boolean value or null
Implementation
@override
Future<bool?> getBool(String key) async {
if (_cache == null) {
await _updateCache();
}
if (_cache == null) return null;
return _cache![key] as bool?;
}