getInt method

  1. @override
Future<int?> getInt(
  1. String key
)
override

Gets an integer value

@param key The key to retrieve the integer from @return A Future that resolves to the integer value or null

Implementation

@override
Future<int?> getInt(String key) async {
  if (_cache == null) {
    await _updateCache();
  }
  if (_cache == null) return null;
  return _cache![key] as int?;
}