getString method
Gets a string value
@param key The key to retrieve the string from @return A Future that resolves to the string value or null
Implementation
@override
Future<String?> getString(String key) async {
if (_cache == null) {
await _updateCache();
}
if (_cache == null) return null;
return _cache![key] as String?;
}