saveBool method

  1. @override
Future<bool> saveBool(
  1. String key,
  2. bool value
)
override

Saves a boolean value

@param key The key to save the boolean under @param value The boolean value to save @return A Future that resolves to true if successful, false otherwise

Implementation

@override
Future<bool> saveBool(String key, bool value) async {
  return await _saveToFile(key, value);
}