saveInt method
Saves an integer value
@param key The key to save the integer under @param value The integer value to save @return A Future that resolves to true if successful, false otherwise
Implementation
@override
Future<bool> saveInt(String key, int value) async {
return await _saveToFile(key, value);
}