saveString method
Saves a string value
@param key The key to save the string under @param value The string value to save @return A Future that resolves to true if successful, false otherwise
Implementation
@override
Future<bool> saveString(String key, String value) async {
return await _saveToFile(key, value);
}