MenuItem<T> class

A generic menu item class

This class represents a menu item with a title and an associated type. It's used to create menu items with specific types for different purposes.

Constructors

Creates a new MenuItem instance
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title of the menu item
final
type → T
The type associated with the menu item
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited