MenuItem<T> constructor

const MenuItem<T>(
  1. String title,
  2. T type
)

Creates a new MenuItem instance

@param title The title of the menu item @param type The type associated with the menu item

Implementation

const MenuItem(this.title, this.type);