LogModel class
Model representing a log entry, extending BaseModel.
Constructors
Properties
- content ↔ String?
-
The log content or message.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime ↔ int?
-
The start time of the model (optional).
getter/setter pairinherited
- tag ↔ String?
-
The tag associated with the log (optional).
getter/setter pair
- type ↔ ModelType
-
The type of the model (api, error, log).
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited