RequestModel class

Model representing an API request, extending BaseModel.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

RequestModel({Map<String, dynamic>? requestHeader, Map<String, List<String>>? responseHeader, String? url, int? requestContentLength, int? responseContentLength, bool isFormatedResponse = false, String? curl, MockApi? mockApi, int? totalFilesSize, dynamic response, int? startTime, int? endTime, dynamic requestBody, Map<String, dynamic>? queryParams, String? message, int? httpCode, String? method, List<UploadFile>? uploadFiles, bool? isSuccess, int? responseTime, String? responseCode, String? responseCodeTitle, int? id})
Constructs a RequestModel with optional parameters.
RequestModel.fromJson(Map<String, dynamic> json)
factory

Properties

curl String?
The curl command for the request (optional).
getter/setter pair
endTime int?
The end time of the request (optional).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
httpCode int?
The HTTP status code of the response.
getter/setter pair
id int?
The unique ID of the request.
getter/setter pair
isFormatedResponse bool
Indicates if the response is formatted.
getter/setter pair
isResponseIsJson bool?
Indicates if the response is JSON.
getter/setter pair
isSuccess bool?
Indicates if the request was successful.
getter/setter pair
message String?
The message associated with the request or response (optional).
getter/setter pair
method String?
The HTTP method used for the request.
getter/setter pair
mockApi MockApi?
The associated MockApi (optional).
getter/setter pair
queryParams Map<String, dynamic>?
The query parameters for the request.
getter/setter pair
requestBody ↔ dynamic
The request body (can be any type).
getter/setter pair
requestContentLength int?
The content length of the request (optional).
getter/setter pair
requestHeader Map<String, dynamic>?
The request headers.
getter/setter pair
response ↔ dynamic
The response data (can be any type).
getter/setter pair
responseCode String?
The response code (optional).
getter/setter pair
responseCodeTitle String?
The title for the response code (optional).
getter/setter pair
responseContentLength int?
The content length of the response (optional).
getter/setter pair
responseHeader Map<String, List<String>>?
The response headers (map of header name to list of values).
getter/setter pair
responseTime int?
The response time in milliseconds (optional).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime int?
The start time of the model (optional).
getter/setter pairinherited
totalFilesSize int?
The total size of uploaded files (optional).
getter/setter pair
type ModelType
The type of the model (api, error, log).
getter/setter pairinherited
uploadFiles List<UploadFile>?
The list of files uploaded with the request.
getter/setter pair
url String?
The request URL.
getter/setter pair

Methods

getFullContent() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited