UploadFile class

Model representing an uploaded file.

Annotations
  • @JsonSerializable.new()

Constructors

UploadFile({String? key, String? path, int? size, String? contentType, String? fileName})
Constructs an UploadFile with optional parameters.
UploadFile.fromJson(Map<String, dynamic> json)
Creates an UploadFile instance from a JSON map.
factory

Properties

contentType String?
The content type of the file (optional).
getter/setter pair
fileName String?
The file name (optional).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String?
The key associated with the file (optional).
getter/setter pair
path String?
The file path (optional).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
The size of the file in bytes (optional).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this UploadFile instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited