get method

Future get(
  1. String key
)

Gets a value

@param key The key to retrieve the value from @return A Future that resolves to the value or null

Implementation

Future<dynamic> get(String key) async {
  return await _getValue<dynamic>(key, _get);
}