Gets a boolean value
@param key The key to retrieve the boolean from @return A Future that resolves to the boolean value or null
Future<bool?> getBool(String key) async { return await _getValue<bool>(key, _getBool); }