getDouble method

Future<double?> getDouble(
  1. String key
)

Gets a double value

@param key The key to retrieve the double from @return A Future that resolves to the double value or null

Implementation

Future<double?> getDouble(String key) async {
  return await _getValue<double>(key, _getDouble);
}