getString method

Future<String?> getString(
  1. String key
)

Gets a string value

@param key The key to retrieve the string from @return A Future that resolves to the string value or null

Implementation

Future<String?> getString(String key) async {
  return await _getValue<String>(key, _getString);
}