SendMail class

The SendMail class provides functionality to send emails using Gmail SMTP.

This class allows sending emails with body, subject, and recipient email address. It uses a Gmail account to send the emails.

Constructors

SendMail()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

sendMail({required String body, required String title, required String email}) Future<String?>
Send an email using Gmail SMTP.