init method
void
init()
Initializes the provider by setting up listeners and loading initial data.
This method registers the provider as a listener to the DevLoggerUI and loads the initial list of models.
Implementation
void init() {
DevLoggerUI.instance.addListener(handleUpdateLog);
root = DevLoggerUI.instance.models;
filter();
}