onTap property

VoidCallback? onTap
final

The callback function to be called when the button is tapped.

If null, the button will not respond to tap gestures.

Implementation

final VoidCallback? onTap;