AppDataViewer class
A widget that displays data in a formatted view using LazyDataViewer.
This widget provides a flexible way to display various types of data including JSON objects, form data, and strings. It uses the LazyDataViewer package for rendering complex data structures in an organized and readable format.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AppDataViewer
Constructors
- AppDataViewer({Key? key, dynamic data, bool isShrinkWrap = false, bool isFormatText = true})
-
Creates an AppDataViewer.
const
Properties
- data → dynamic
-
The data to display.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFormatText → bool
-
Whether to use shrink wrap for the LazyDataViewer.
final
- isShrinkWrap → bool
-
Whether to use shrink wrap for the LazyDataViewer.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Builds the UI for the AppDataViewer.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited