build method
Builds the UI for the AppDataViewer.
Returns a Widget that displays the data in a formatted view.
Implementation
@override
Widget build(BuildContext context) {
return _getView(data);
}
Builds the UI for the AppDataViewer.
Returns a Widget that displays the data in a formatted view.
@override
Widget build(BuildContext context) {
return _getView(data);
}