child property
The content to display inside the bottom sheet.
This widget will be wrapped in a container with consistent styling.
Implementation
final Widget child;
The content to display inside the bottom sheet.
This widget will be wrapped in a container with consistent styling.
final Widget child;