ActionButton class
Represents a custom action button for ActionTwoText.
Constructors
- ActionButton({String? title, Widget? titleWidget, VoidCallback? onTap})
-
Creates an ActionButton with optional
title,titleWidget, andonTap.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTap ↔ VoidCallback?
-
The callback when the button is tapped.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
The text title of the button.
getter/setter pair
- titleWidget ↔ Widget?
-
The widget to display as the button (overrides title if provided).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited