ActionTwoText class

A widget that displays two pieces of text with optional copy and send actions.

Shows first and second text, with customizable styles, colors, and action buttons.

Inheritance

Constructors

ActionTwoText({Key? key, required String first, required String second, TextStyle? firstStyle, String separator = ": ", TextStyle? secondStyle, List<ActionButton>? actions, bool isShowCopy = true, bool isShowSend = true, Color? firstColor, dynamic sendText(String? content, String title)?, Color? secondColor})
Creates an ActionTwoText widget.
const

Properties

actions List<ActionButton>?
List of custom action buttons to display.
final
first String
The first (label) text.
final
firstColor Color?
The color for first text.
final
firstStyle TextStyle?
The text style for first.
final
hashCode int
The hash code for this object.
no setterinherited
isShowCopy bool
Whether to show the copy icon.
final
isShowSend bool
Whether to show the send icon.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second String
The second (value) text.
final
secondColor Color?
The color for second text.
final
secondStyle TextStyle?
The text style for second.
final
sendText → dynamic Function(String? content, String title)?
Callback for sending the second text, with first as the title.
final
separator String
The separator string between first and second.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited