isVerticalAlign property
Determines whether the text field should be aligned vertically or horizontally.
Implementation
final bool isVerticalAlign;
Determines whether the text field should be aligned vertically or horizontally.
final bool isVerticalAlign;