onChanged property
Callback function that is called when the text in the text field changes.
Implementation
final Function(String? value)? onChanged;
Callback function that is called when the text in the text field changes.
final Function(String? value)? onChanged;