RatioTwoText class

A widget that displays two pieces of text in a row with flexible layout and optional actions.

Inheritance

Constructors

RatioTwoText({Key? key, required dynamic first, required dynamic second, TextStyle? firstStyle, String separator = ": ", TextStyle? secondStyle, int firstFlex = 1, int secondFlex = 2, SendTextFunction? sendText})
Creates a RatioTwoText widget.
const

Properties

first → dynamic
The first (label) value.
final
firstFlex int
The flex value for the first text.
final
firstStyle TextStyle?
The text style for first.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second → dynamic
The second (value) value.
final
secondFlex int
The flex value for the second text.
final
secondStyle TextStyle?
The text style for second.
final
sendText SendTextFunction?
Callback for sending the second text, with first as the title.
final
separator String
The separator string between first and second.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited