common_utils library

Common utilities library

This library provides common utility functions used throughout the application.

Functions

isAllNotNullOrEmpty(List objects) bool
Checks if all objects in a list are not null and not empty
isNotNullOrEmpty(dynamic object) bool
Checks if an object is not null and not empty
isNullOrEmpty(dynamic object) bool
Checks if an object is null or empty
isOneNullOrEmpty(List objects) bool
Checks if any object in a list is null or empty
showToast(String? text, {bool isSuccess = true}) → void
Shows a toast message