isNotNullOrEmpty function
Checks if an object is not null and not empty
@param object The object to check @return true if the object is not null and not empty, false otherwise
Implementation
bool isNotNullOrEmpty(dynamic object) {
if (object == null) return false;
if (object is String) return object.isNotEmpty == true;
if (object is Map) return object.isNotEmpty;
if (object is Iterable) return object.isNotEmpty;
return true;
}