pop static method

Future pop({
  1. dynamic result,
  2. bool isRootNavigator = true,
})

Pops the current screen off the navigation stack

result - Optional result to pass back to the previous screen isRootNavigator - Flag indicating whether to use the root navigator (default is true)

Returns a Future that completes when the pop operation is finished

Implementation

static Future pop({dynamic result, bool isRootNavigator = true}) async {
  Navigator.of(libNavigatorKey.currentContext!,
          rootNavigator: isRootNavigator)
      .pop(result);
}