AppStyles class
Class that defines various styles used across the application.
Constructors
Properties
-
Text style for buttons in the app.
final
- defaultTextStyle → TextStyle
-
Default text style for general use in the app.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputContentStyle → TextStyle
-
Text style for content within input fields.
final
- inputLabelStyle → TextStyle
-
Text style for labels of input fields.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle16 → TextStyle
-
Text style with a font size of 16 used in various parts of the app.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited