DevLoggerUIAbstract class
Abstract base class for API Logger implementations.
Contains core properties such as saveManager, navigatorKey, isLogEnabled, isLogCurl, and the list of models.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLogCurl ↔ bool
-
Whether curl logging is enabled.
getter/setter pair
- isLogEnabled ↔ bool
-
Whether logging is enabled.
getter/setter pair
-
models
↔ List<
BaseModel> -
The list of models tracked by the logger.
getter/setter pair
-
The navigator key for navigation operations.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saveManager ↔ SaveManager
-
The save manager for persistent storage.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited