FileName class

A class for managing file names with name and type

This class represents a file with a name and type, and provides functionality to get the full file name.

Constructors

FileName({String? name, String? type})
Creates a new FileName instance

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the file
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of the file
getter/setter pair

Methods

getFileName() String
Gets the full file name
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited