MenuItem<T> constructor
const
MenuItem<T> (
- String title,
- T type
Creates a new MenuItem instance
@param title The title of the menu item @param type The type associated with the menu item
Implementation
const MenuItem(this.title, this.type);