ErrorModel class
Model representing an error, extending BaseModel.
Constructors
- ErrorModel({String? content, String? exceptionName, int? startTime, bool isUIError = true, StackTrace? stackTrace, dynamic error, FlutterErrorDetails? errorDetails})
- Constructs an ErrorModel with optional details.
Properties
- content ↔ String?
-
The error content or message.
getter/setter pair
- error ↔ dynamic
-
The error object (can be any type).
getter/setter pair
- errorDetails ↔ FlutterErrorDetails?
-
Flutter error details (if available).
getter/setter pair
- exceptionName ↔ String?
-
The name of the exception (if any).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isUIError ↔ bool
-
Indicates if this is a UI error.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace ↔ StackTrace?
-
The stack trace associated with the error.
getter/setter pair
- startTime ↔ int?
-
The start time of the model (optional).
getter/setter pairinherited
- type ↔ ModelType
-
The type of the model (api, error, log).
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited