MockApi class
Model representing a mock API configuration.
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod ↔ String?
-
The HTTP method for the mock API.
getter/setter pair
- mockResponse ↔ String?
-
The mock response content.
getter/setter pair
- mockUrl ↔ String?
-
The mock URL to use instead of the original.
getter/setter pair
- originalUrl ↔ String?
-
The original URL to be mocked.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ MockType?
-
The type of mock (see MockType).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this MockApi instance to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited