SaveManager class
An abstract class for saving and retrieving data
This abstract class defines the interface for saving and retrieving data of various types (String, int, double, bool) from different storage mechanisms.
- Implementers
Constructors
-
SaveManager({SaveValue<
String> ? saveString, GetValue<String?> ? getString, SaveValue<int> ? saveInt, GetValue<int> ? getInt, SaveValue<double> ? saveDouble, GetValue<double?> ? getDouble, SaveValue<bool> ? saveBool, GetValue<bool?> ? getBool, GetValue? get, GetValue<bool> ? hasKey, GetValue<bool> ? remove}) - Creates a new SaveManager instance
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
String key) → Future - Gets a value
-
getBool(
String key) → Future< bool?> - Gets a boolean value
-
getDouble(
String key) → Future< double?> - Gets a double value
-
getInt(
String key) → Future< int?> - Gets an integer value
-
getString(
String key) → Future< String?> - Gets a string value
-
hasKey(
String key) → Future< bool> - Checks if a key exists
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → Future< bool> - Removes a key
-
saveBool(
String key, bool value) → Future< bool?> - Saves a boolean value
-
saveDouble(
String key, double value) → Future< bool?> - Saves a double value
-
saveInt(
String key, int value) → Future< bool?> - Saves an integer value
-
saveString(
String key, String value) → Future< bool?> - Saves a string value
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited