getBool method

Future<bool?> getBool(
  1. String key
)

Gets a boolean value

@param key The key to retrieve the boolean from @return A Future that resolves to the boolean value or null

Implementation

Future<bool?> getBool(String key) async {
  return await _getValue<bool>(key, _getBool);
}