Gets an integer value
@param key The key to retrieve the integer from @return A Future that resolves to the integer value or null
Future<int?> getInt(String key) async { return await _getValue<int>(key, _getInt); }