saveBool method
Saves a boolean value
@param key The key to save the boolean under @param value The boolean value to save @return A Future that resolves to true if successful, false otherwise
Implementation
Future<bool?> saveBool(String key, bool value) async {
return await _save<bool>(key, value, _saveBool);
}