onTap property
The callback function to be called when the button is tapped.
If null, the button will not respond to tap gestures.
Implementation
final VoidCallback? onTap;
The callback function to be called when the button is tapped.
If null, the button will not respond to tap gestures.
final VoidCallback? onTap;