ui/widgets/item_api_action_bottom_sheeet library
A bottom sheet widget that displays a list of API action menu items.
ItemApiActionBottomSheeet is a generic stateless widget that shows a list of MenuItems in a styled bottom sheet, allowing the user to select an action. When an item is tapped, the bottom sheet is closed and the selected item's type is returned.
Classes
-
ItemApiActionBottomSheeet<
T> - A bottom sheet widget that displays a list of API action menu items.
Enums
- ItemApiActionType
- Types of API actions available in the bottom sheet.
- ItemErrorActionType
- Types of error actions available in the bottom sheet.