SimpleRichTextData class

Data for a single rich text or widget span in SimpleRichText.

Constructors

SimpleRichTextData({String? text, TextStyle? style, Widget? widget, int? maxLine})
Creates a SimpleRichTextData with either text or widget.

Properties

hashCode int
The hash code for this object.
no setterinherited
maxLine int?
The maximum number of lines for the text.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
The style for the text.
getter/setter pair
text String?
The text to display (if not using a widget).
getter/setter pair
widget Widget?
The widget to display (if not using text).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited